summaryrefslogtreecommitdiffstats
path: root/parts/outputviews/directorystatusmessagefilter.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'parts/outputviews/directorystatusmessagefilter.cpp')
-rw-r--r--parts/outputviews/directorystatusmessagefilter.cpp72
1 files changed, 36 insertions, 36 deletions
diff --git a/parts/outputviews/directorystatusmessagefilter.cpp b/parts/outputviews/directorystatusmessagefilter.cpp
index 5738f41d..02629797 100644
--- a/parts/outputviews/directorystatusmessagefilter.cpp
+++ b/parts/outputviews/directorystatusmessagefilter.cpp
@@ -13,7 +13,7 @@
#include "directorystatusmessagefilter.moc"
#include "makeitem.h"
-#include <qregexp.h>
+#include <tqregexp.h>
#include <kdebug.h>
DirectoryStatusMessageFilter::DirectoryStatusMessageFilter( OutputFilter& next )
@@ -21,9 +21,9 @@ DirectoryStatusMessageFilter::DirectoryStatusMessageFilter( OutputFilter& next )
{
}
-void DirectoryStatusMessageFilter::processLine( const QString& line )
+void DirectoryStatusMessageFilter::processLine( const TQString& line )
{
- QString dir;
+ TQString dir;
if ( matchEnterDir( line, dir ) )
{
emit item( new EnteringDirectoryItem( dir, line ) );
@@ -40,7 +40,7 @@ void DirectoryStatusMessageFilter::processLine( const QString& line )
// simple helper function - checks whether we entered a new directory
// (locale and Utf8 aware)
-bool DirectoryStatusMessageFilter::matchEnterDir( const QString& line, QString& dir )
+bool DirectoryStatusMessageFilter::matchEnterDir( const TQString& line, TQString& dir )
{
// make outputs localised strings in Utf8 for entering/leaving directories...
static const unsigned short fr_enter[] =
@@ -70,28 +70,28 @@ bool DirectoryStatusMessageFilter::matchEnterDir( const QString& line, QString&
0x412,0x445,0x43e,0x434,0x20,0x432,0x20,0x43a,0x430,0x442,0x430,0x43b,0x43e,0x433
};
- static const QString fr_e( (const QChar*)fr_enter, sizeof(fr_enter) / 2 );
- static const QString pl_e( (const QChar*)pl_enter, sizeof(pl_enter) / 2 );
- static const QString ja_e( (const QChar*)ja_enter, sizeof(ja_enter) / 2 );
- static const QString ko_e( (const QChar*)ko_enter, sizeof(ko_enter) / 2 );
- static const QString ko_b( (const QChar*)ko_behind, sizeof(ko_behind) / 2 );
- static const QString pt_br_e( (const QChar*)pt_br_enter, sizeof(pt_br_enter) / 2 );
- static const QString ru_e( (const QChar*)ru_enter, sizeof(ru_enter) / 2 );
- static const QString en_e("Entering directory");
- static const QString de_e1("Wechsel in das Verzeichnis Verzeichnis");
- static const QString de_e2("Wechsel in das Verzeichnis");
- static const QString es_e("Cambiando a directorio");
- static const QString nl_e("Binnengaan van directory");
+ static const TQString fr_e( (const TQChar*)fr_enter, sizeof(fr_enter) / 2 );
+ static const TQString pl_e( (const TQChar*)pl_enter, sizeof(pl_enter) / 2 );
+ static const TQString ja_e( (const TQChar*)ja_enter, sizeof(ja_enter) / 2 );
+ static const TQString ko_e( (const TQChar*)ko_enter, sizeof(ko_enter) / 2 );
+ static const TQString ko_b( (const TQChar*)ko_behind, sizeof(ko_behind) / 2 );
+ static const TQString pt_br_e( (const TQChar*)pt_br_enter, sizeof(pt_br_enter) / 2 );
+ static const TQString ru_e( (const TQChar*)ru_enter, sizeof(ru_enter) / 2 );
+ static const TQString en_e("Entering directory");
+ static const TQString de_e1("Wechsel in das Verzeichnis Verzeichnis");
+ static const TQString de_e2("Wechsel in das Verzeichnis");
+ static const TQString es_e("Cambiando a directorio");
+ static const TQString nl_e("Binnengaan van directory");
//@todo: other translations!
// we need a QRegExp because KRegExp is not Utf8 aware.
// 0x00AB is LEFT-POINTING DOUBLE ANGLE QUOTATION MARK
// 0X00BB is RIGHT-POINTING DOUBLE ANGLE QUOTATION MARK
- static QRegExp dirChange(QString::fromLatin1(".*: (.+) (`|") + QChar(0x00BB) + QString::fromLatin1(")(.*)('|") + QChar(0x00AB) + QString::fromLatin1(")(.*)"));
- static QRegExp enEnter(QString::fromLatin1(".*: Entering directory"));
+ static TQRegExp dirChange(TQString::fromLatin1(".*: (.+) (`|") + TQChar(0x00BB) + TQString::fromLatin1(")(.*)('|") + TQChar(0x00AB) + TQString::fromLatin1(")(.*)"));
+ static TQRegExp enEnter(TQString::fromLatin1(".*: Entering directory"));
kdDebug(9004) << "Directory filter line " << line << endl;
// avoid QRegExp if possible. This regex performs VERY badly with large inputs,
// and the input required is very short if these strings match.
if(line.find(en_e) > -1 ||
line.find(fr_e) > -1 ||
@@ -118,7 +118,7 @@ bool DirectoryStatusMessageFilter::matchEnterDir( const QString& line, QString&
// simple helper function - checks whether we left a directory
// (locale and Utf8 aware).
-bool DirectoryStatusMessageFilter::matchLeaveDir( const QString& line, QString& dir )
+bool DirectoryStatusMessageFilter::matchLeaveDir( const TQString& line, TQString& dir )
{
static const unsigned short fr_leave[] =
{ 'Q','u','i','t','t','e',' ','l','e',' ','r',0xe9,'p','e','r','t','o','i','r','e'
@@ -143,26 +143,26 @@ bool DirectoryStatusMessageFilter::matchLeaveDir( const QString& line, QString&
0x20,0xb514,0xb809,0xd1a0,0xb9ac
};
- static const QString fr_l( (const QChar*)fr_leave, sizeof(fr_leave) / 2 );
- static const QString ja_l( (const QChar*)ja_leave, sizeof(ja_leave) / 2 );
- static const QString ko_l( (const QChar*)ko_leave, sizeof(ko_leave) / 2 );
- static const QString ko_b( (const QChar*)ko_behind, sizeof(ko_behind) / 2 );
- static const QString pt_br_l( (const QChar*)pt_br_leave, sizeof(pt_br_leave) / 2 );
- static const QString ru_l( (const QChar*)ru_leave, sizeof(ru_leave) / 2 );
- static const QString en_l("Leaving directory");
- static const QString de_l1("Verlassen des Verzeichnisses Verzeichnis");
- static const QString de_l2("Verlassen des Verzeichnisses");
- static const QString es_l("Saliendo directorio");
- static const QString nl_l("Verdwijnen uit directory");
- static const QString po_l("Opuszczam katalog");
+ static const TQString fr_l( (const TQChar*)fr_leave, sizeof(fr_leave) / 2 );
+ static const TQString ja_l( (const TQChar*)ja_leave, sizeof(ja_leave) / 2 );
+ static const TQString ko_l( (const TQChar*)ko_leave, sizeof(ko_leave) / 2 );
+ static const TQString ko_b( (const TQChar*)ko_behind, sizeof(ko_behind) / 2 );
+ static const TQString pt_br_l( (const TQChar*)pt_br_leave, sizeof(pt_br_leave) / 2 );
+ static const TQString ru_l( (const TQChar*)ru_leave, sizeof(ru_leave) / 2 );
+ static const TQString en_l("Leaving directory");
+ static const TQString de_l1("Verlassen des Verzeichnisses Verzeichnis");
+ static const TQString de_l2("Verlassen des Verzeichnisses");
+ static const TQString es_l("Saliendo directorio");
+ static const TQString nl_l("Verdwijnen uit directory");
+ static const TQString po_l("Opuszczam katalog");
- // we need a QRegExp because KRegExp is not Utf8 aware.
+ // we need a TQRegExp because KRegExp is not Utf8 aware.
// 0x00AB is LEFT-POINTING DOUBLE ANGLE QUOTATION MARK
// 0X00BB is RIGHT-POINTING DOUBLE ANGLE QUOTATION MARK
- static QRegExp dirChange(QString::fromLatin1(".*: (.+) (`|") + QChar(0x00BB) + QString::fromLatin1(")(.*)('|") + QChar(0x00AB) + QString::fromLatin1(")(.*)"));
+ static TQRegExp dirChange(TQString::fromLatin1(".*: (.+) (`|") + TQChar(0x00BB) + TQString::fromLatin1(")(.*)('|") + TQChar(0x00AB) + TQString::fromLatin1(")(.*)"));
- // avoid QRegExp if possible. This regex performs VERY badly with large inputs,
+ // avoid TQRegExp if possible. This regex performs VERY badly with large inputs,
// and the input required is very short if these strings match.
if(line.find(en_l) > -1 ||
line.find(fr_l) > -1 ||
@@ -70,28 +70,28 @@ bool DirectoryStatusMessageFilter::matchEnterDir( const QString& line, QString&
//@todo: other translations!
- // we need a QRegExp because KRegExp is not Utf8 aware.
+ // we need a TQRegExp because KRegExp is not Utf8 aware.
// 0x00AB is LEFT-POINTING DOUBLE ANGLE QUOTATION MARK
// 0X00BB is RIGHT-POINTING DOUBLE ANGLE QUOTATION MARK
@@ -70,28 +70,28 @@ bool DirectoryStatusMessageFilter::matchEnterDir( const QString& line, QString&
kdDebug(9004) << "Directory filter line " << line << endl;
- // avoid QRegExp if possible. This regex performs VERY badly with large inputs,
+ // avoid TQRegExp if possible. This regex performs VERY badly with large inputs,
// and the input required is very short if these strings match.
if(line.find(en_e) > -1 ||